@@ -238,7 +238,13 @@ def _PyScons(env, target, source, scons, options="-Q", sig_options="", clean = T
     options += " temp=" + TEMP + " n=" + scons  
     cmd = "scons %s %s -f%s %s" % (options, sig_options, scons, args)
     cleancmd = cmd + " --clean"
-    
+
+    exe = os.path.join(basename, "EXECUTE")
+    file = open(exe, 'w')
+    print >>file, "#!/bin/bash"
+    print >>file, cmd + " $*"
+    os.chmod(exe, 0755)
+
     if env.GetOption("clean") and not clean: 
         env.Execute(cleancmd)
         env.Execute(Delete(TEMP))
